@@ -12,13 +12,15 @@
 #include <QObject>
 #include <QTest>
 
+#include <config.h>
+
 class KateTextBufferTest : public QObject
 {
     Q_OBJECT
 
 public:
     KateTextBufferTest();
-    virtual ~KateTextBufferTest();
+    ~KateTextBufferTest() override;
 
 private Q_SLOTS:
     void basicBufferTest();
@@ -28,7 +30,11 @@ private Q_SLOTS:
     void foldingTest();
     void nestedFoldingTest();
     void saveFileInUnwritableFolder();
+    void lineLengthLimit();
+
+#if HAVE_KAUTH
     void saveFileWithElevatedPrivileges();
+#endif
 };
 
 #endif // KATETEXTBUFFERTEST_H
