@@ -499,7 +499,7 @@ KateViewConfig::KateViewConfig()
         return inBounds(0, value, 100);
     }));
     addConfigEntry(ConfigEntry(DynWordWrapIndicators, "Dynamic Word Wrap Indicators", QString(), 1, [](const QVariant &value) {
-        return inBounds(1, value, 3);
+        return inBounds(0, value, 2);
     }));
     addConfigEntry(ConfigEntry(DynWrapAnywhere, "Dynamic Wrap not at word boundaries", QStringLiteral("dynamic-word-wrap-anywhere"), false));
     addConfigEntry(ConfigEntry(DynWrapAtStaticMarker, "Dynamic Word Wrap At Static Marker", QString(), false));
@@ -550,7 +550,6 @@ KateViewConfig::KateViewConfig()
                                    return inBounds(0, value, 99);
                                }));
     addConfigEntry(ConfigEntry(WordCompletionRemoveTail, "Word Completion Remove Tail", QString(), true));
-    addConfigEntry(ConfigEntry(ShowFocusFrame, "Show Focus Frame Around Editor", QString(), true));
     addConfigEntry(ConfigEntry(ShowDocWithCompletion, "Show Documentation With Completion", QString(), true));
     addConfigEntry(ConfigEntry(MultiCursorModifier, "Multiple Cursor Modifier", QString(), (int)Qt::AltModifier));
     addConfigEntry(ConfigEntry(ShowFoldingOnHoverOnly, "Show Folding Icons On Hover Only", QString(), true));
@@ -946,6 +945,11 @@ void KateRendererConfig::setFont(const QFont &font)
     configStart();
     m_font = font;
     m_fontSet = true;
+
+    // Set full hinting instead to ensure the letters are aligned properly, bug 482659
+    // https://codereview.qt-project.org/c/qt/qtbase/+/546168
+    m_font.setHintingPreference(QFont::PreferFullHinting);
+
     configEnd();
 }
 
