@@ -53,20 +53,6 @@
 #include <QTextToSpeech>
 #include <QTimer>
 
-// BEGIN unit test mode
-static bool kateUnitTestMode = false;
-
-void KTextEditor::EditorPrivate::enableUnitTestMode()
-{
-    kateUnitTestMode = true;
-}
-
-bool KTextEditor::EditorPrivate::unitTestMode()
-{
-    return kateUnitTestMode;
-}
-// END unit test mode
-
 KTextEditor::EditorPrivate::EditorPrivate(QPointer<KTextEditor::EditorPrivate> &staticInstance)
     : KTextEditor::Editor(this)
     , m_aboutData(QStringLiteral("katepart"),
@@ -484,7 +470,7 @@ void KTextEditor::EditorPrivate::copyToClipboard(const QString &text, const QStr
 
     // LRU, kill potential duplicated, move new entry to top
     // cut after X entries
-    auto entry = ClipboardEntry{text, fileName};
+    auto entry = ClipboardEntry{.text=text, .fileName=fileName};
     m_clipboardHistory.removeOne(entry);
     m_clipboardHistory.prepend(entry);
     if (m_clipboardHistory.size() > m_viewConfig->clipboardHistoryEntries()) {
@@ -539,7 +525,7 @@ void KTextEditor::EditorPrivate::saveSearchReplaceHistoryModels()
 KSharedConfigPtr KTextEditor::EditorPrivate::config()
 {
     // use dummy config for unit tests!
-    if (KTextEditor::EditorPrivate::unitTestMode()) {
+    if (QStandardPaths::isTestModeEnabled()) {
         return KSharedConfig::openConfig(QStringLiteral("katepartrc-unittest"), KConfig::SimpleConfig, QStandardPaths::TempLocation);
     }
 
