@@ -9,11 +9,10 @@
 #ifndef _KATE_TEMPLATE_HANDLER_H_
 #define _KATE_TEMPLATE_HANDLER_H_
 
-#include <QMap>
+#include <QList>
 #include <QObject>
 #include <QPointer>
 #include <QString>
-#include <QVector>
 
 #include <katescript.h>
 #include <ktexteditor/cursor.h>
@@ -197,7 +196,7 @@ private:
     // Describes a single template field, e.g. ${foo}.
     struct TemplateField {
         // up-to-date range for the field
-        QSharedPointer<KTextEditor::MovingRange> range;
+        std::shared_ptr<KTextEditor::MovingRange> range;
         // contents of the field, i.e. identifier or function to call
         QString identifier;
         // default value, if applicable; else empty
@@ -218,7 +217,7 @@ private:
         }
     };
     // List of all template fields in the inserted snippet. @see sortFields()
-    QVector<TemplateField> m_fields;
+    QList<TemplateField> m_fields;
 
     // Get the template field which contains @p range.
     const TemplateField fieldForRange(KTextEditor::Range range) const;
@@ -228,7 +227,7 @@ private:
 
     /// A range that occupies the whole range of the inserted template.
     /// When the an edit happens outside it, the template handler gets closed.
-    QSharedPointer<KTextEditor::MovingRange> m_wholeTemplateRange;
+    std::shared_ptr<KTextEditor::MovingRange> m_wholeTemplateRange;
 
     /// Set to true when currently updating dependent fields, to prevent recursion.
     bool m_internalEdit;
